pub struct RuntimeContext { /* private fields */ }Expand description
AINL runtime context for execution
Implementations
Sourceimpl RuntimeContext
impl RuntimeContext
Sourcepub fn new(config: RuntimeConfig, memory: Option<GraphMemory>) -> Self
pub fn new(config: RuntimeConfig, memory: Option<GraphMemory>) -> Self
Create a new runtime context with the given memory backend
Sourcepub fn record_delegation(
&self,
delegated_to: String,
trace_event: Option<Value>,
) -> Result<Uuid, String>
pub fn record_delegation( &self, delegated_to: String, trace_event: Option<Value>, ) -> Result<Uuid, String>
Record an agent delegation as an episode node
Sourcepub fn record_tool_execution(
&self,
tool_name: String,
trace_event: Option<Value>,
) -> Result<Uuid, String>
pub fn record_tool_execution( &self, tool_name: String, trace_event: Option<Value>, ) -> Result<Uuid, String>
Record a tool execution as an episode node
Sourcepub fn store(&self) -> Option<&dyn GraphStore>
pub fn store(&self) -> Option<&dyn GraphStore>
Get direct access to the underlying store for advanced queries